﻿using System;
using System.Windows.Forms;

using TestClient.SampleService;

namespace TestClient
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 클라이언트
        /// </summary>
        private SampleServiceClient client;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.client = new SampleServiceClient("BasicHttpBinding_ISampleService");

            this.testButton1.Click += testButton1_Click;
            this.testButton2.Click += testButton2_Click;
            this.clearButton.Click += clearButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 요청/응답 작업하기 버튼 클릭시 처리하기 - testButton1_Click(sender, e)

        /// <summary>
        /// 요청/응답 작업하기 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void testButton1_Click(object sender, EventArgs e)
        {
            try
            {
                this.messageListBox.Items.Add("요청/응답 작업을 시작합니다 : " + DateTime.Now.ToString("yyyy-MM-dd HH:mm:ss"));

                this.testButton1.Enabled = false;

                this.messageListBox.Items.Add(this.client.RequestReplyOperation());

                this.testButton1.Enabled = true;

                this.messageListBox.Items.Add("요청/응답 작업을 완료합니다 : " + DateTime.Now.ToString("yyyy-MM-dd HH:mm:ss"));

                this.messageListBox.Items.Add(string.Empty);
            }
            catch(Exception exception)
            {
                MessageBox.Show(exception.Message);
            }
        }

        #endregion
        #region 요청/응답 작업하기 (예외 발생) 버튼 클릭시 처리하기 - testButton1_Click(sender, e)

        /// <summary>
        /// 요청/응답 작업하기 (예외 발생) 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void testButton2_Click(object sender, EventArgs e)
        {
            try
            {
                this.messageListBox.Items.Add("요청/응답 작업(예외 발생)을 시작합니다 : " + DateTime.Now.ToString("yyyy-MM-dd HH:mm:ss"));

                this.testButton1.Enabled = false;

                this.messageListBox.Items.Add(this.client.RequestReplyOperationThrowsException());

                this.testButton1.Enabled = true;

                this.messageListBox.Items.Add("요청/응답 작업(예외 발생)을 완료합니다 : " + DateTime.Now.ToString("yyyy-MM-dd HH:mm:ss"));

                this.messageListBox.Items.Add(string.Empty);
            }
            catch(Exception exception)
            {
                MessageBox.Show(exception.Message);
            }
        }

        #endregion
        #region 목록 지우기 버튼 클릭시 처리하기 - testButton1_Click(sender, e)

        /// <summary>
        /// 목록 지우기 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void clearButton_Click(object sender, EventArgs e)
        {
            this.messageListBox.Items.Clear();
        }

        #endregion
    }
}